@@ -71,7 +71,7 @@ X<?cs var:html_escape(R90C) ?>𒴂Ă܂B<?cs var:html_escape(BBS_RES_MAX) ?>𒴂
 <br><br>
 
 <?cs if:!r100 ?>
-<form class="comment" method="POST" action="<?cs var:html_escape(CGIURI) ?>/bbs.cgi" enctype="multipart/form-data">
+<form class="comment" method="POST" action="<?cs var:html_escape(CGIURI) ?>/bbs.cgi?guid=on" enctype="multipart/form-data">
 <input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>">
 <input type="hidden" name="key" value="<?cs var:html_escape(KEY) ?>">
 <input type="hidden" name="time" value="<?cs var:html_escape(TimeStamp) ?>">
