@@ -57,6 +57,8 @@
 <input id="THREAD_POSITION" type="text" name="THREAD_POSITION" value="<?cs var:html_escape(THREAD_POSITION) ?>" /><br />
 <label for="BBS_READONLY">キャップのみ書き込み可能にする</label>
 <input id="BBS_READONLY" type="checkbox" name="BBS_READONLY" value="caps" <?cs if:BBS_READONLY ?>checked="checked"<?cs /if ?>/>キャップのみ許可<br />
+<label for="BBS_PCONLY">携帯からの投稿を拒否する</label>
+<input id="BBS_PCONLY" type="checkbox" name="BBS_PCONLY" value="checked" <?cs if:BBS_PCONLY ?>checked="checked"<?cs /if ?>/>携帯からの投稿を拒否<br />
 <input type="submit" name="s" value="更新" />
 </div>
 
