@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2010 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Akismet.pm 1481 2007-10-24 14:13:30Z hikarin $
+# $Id: Akismet.pm 2028 2010-06-22 16:39:35Z hikarin $
 #
 
 package Img0ch::Plugin::Filter::Akismet;
@@ -33,6 +33,7 @@ sub check {
         URL        => $iApp->bbs()->url(''),
         USER_AGENT => $iRequest->credit(),
     ) or die __PACKAGE__ . ': KEY VERIFICATION FAILURE', "\n";
+    my $agent = $iRequest->get_header('user-agent');
     my $mail = $iConfig->get('akismet.mail') ? $iApp->get_mail() : '';
     my $referer
         = $iConfig->get('akismet.referer')
@@ -43,6 +44,7 @@ sub check {
 
         #        COMMENT_CONTENT     => $iApp->get_comment(),
         #        COMMENT_AUTHOR      => $iApp->get_name(),
+        COMMENT_USER_AGENT  => $agent,
         COMENT_AUTHOR_EMAIL => $mail,
         REFERRER            => $referer,
     ) or die __PACKAGE__ . ': AKISMET CONNECTION FAILURE', "\n";
