@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Install.pm 2002 2010-02-21 13:28:07Z hikarin $
+# $Id: Install.pm 2027 2010-05-13 16:02:51Z hikarin $
 #
 
 package Img0ch::Plugin::Install;
@@ -315,3 +315,6 @@ sub uninstall {
     return 1;
 }
 
+1;
+__END__
+
