@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: BBS.pm 1901 2009-12-31 02:40:20Z hikarin $
+# $Id: BBS.pm 2029 2010-07-05 15:46:30Z hikarin $
 #
 
 package Zeromin::BBS;
@@ -589,7 +589,7 @@ sub gets {
     my ( $zBBS, $bbs_ids, $unijp, $zCategory ) = @_;
     my $result = [];
     map { push @$result, $zBBS->get( $_, $unijp, $zCategory ) } @$bbs_ids;
-    @$result = grep { !$_->{id} } @$result;
+    @$result = grep { Img0ch::Kernel::intval($_->{id}) > 0 } @$result;
     return $result;
 }
 
