@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2010 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Thread.pm 1481 2007-10-24 14:13:30Z hikarin $
+# $Id: Thread.pm 1901 2009-12-31 02:40:20Z hikarin $
 #
 
 package Zeromin::Log::Thread;
@@ -28,7 +28,7 @@ sub new {
 
     bless {
         __bbs => ( $iBBS->get_name() || 'test' ),
-        __rs => $iKernel->get_repos( $iKernel->get_repos_path('log') ),
+        __rs => $iKernel->get_repos( $iKernel->get_repos_path('restrict') ),
     }, $iClass;
 }
 
@@ -38,7 +38,7 @@ sub all {
     my ($zLogThr) = @_;
     my $bbs       = $zLogThr->{__bbs};
     my $ret       = [];
-    my @data = split "\n", $zLogThr->{__rs}->get_binary("I:F:T#2.${bbs}");
+    my @data = split "\n", $zLogThr->{__rs}->get_binary("I:F:T.${bbs}");
 
     for my $one (@data) {
         my ( $ip_group, $time, $ip ) = split "\t", $one, 3;
@@ -56,7 +56,7 @@ sub all {
 sub all_with_page {
     my ( $zLogThr, $item_per_page, $offset ) = @_;
 
-    require Data::Page;
+    defined $Data::Page::VERSION or require Data::Page;
     my $entries = $zLogThr->all();
     my $page = Data::Page->new( scalar @$entries, $item_per_page, $offset );
     return ( [ $page->splice($entries) ], $page );
