@@ -55,34 +55,36 @@ additions to C<Params::Util> may clash)
 
 =cut
 
-BEGIN {
-	require 5.004;
-}
+use 5.00503;
 use strict;
-use overload     ();
-use Exporter     ();
-use Scalar::Util ();
+require overload;
+require Exporter;
+require Scalar::Util;
+require DynaLoader;
 
 use vars qw{$VERSION @ISA @EXPORT_OK %EXPORT_TAGS};
-BEGIN {
-	$VERSION   = '0.25';
-	@ISA       = 'Exporter';
 
-	@EXPORT_OK = qw{
-		_STRING     _IDENTIFIER
-		_CLASS      _CLASSISA   _SUBCLASS  _DRIVER
-		_POSINT 
-		_SCALAR     _SCALAR0
-		_ARRAY      _ARRAY0     _ARRAYLIKE
-		_HASH       _HASH0      _HASHLIKE
-		_CODE       _CODELIKE   _CALLABLE
-		_INVOCANT
-		_INSTANCE   _SET        _SET0
-		_HANDLE
-		};
+$VERSION   = '0.37';
+@ISA       = ('Exporter', 'DynaLoader');
+@EXPORT_OK = qw{
+	_STRING     _IDENTIFIER
+	_CLASS      _CLASSISA   _SUBCLASS  _DRIVER
+	_NUMBER     _POSINT     _NONNEGINT
+	_SCALAR     _SCALAR0
+	_ARRAY      _ARRAY0     _ARRAYLIKE
+	_HASH       _HASH0      _HASHLIKE
+	_CODE       _CODELIKE
+	_INVOCANT   _REGEX      _INSTANCE
+	_SET        _SET0
+	_HANDLE
+	};
+%EXPORT_TAGS = ( ALL => \@EXPORT_OK );
 
-	%EXPORT_TAGS = (ALL => \@EXPORT_OK);
-}
+eval {
+	local $ENV{PERL_DL_NONLAZY} = 0 if $ENV{PERL_DL_NONLAZY};
+	bootstrap Params::Util $VERSION;
+	1;
+} unless $ENV{PERL_PARAMS_UTIL_PP};
 
 
 
@@ -116,9 +118,11 @@ C<undef> if not.
 
 =cut
 
+eval <<'END_PERL' unless defined &_STRING;
 sub _STRING ($) {
 	(defined $_[0] and ! ref $_[0] and length($_[0])) ? $_[0] : undef;
 }
+END_PERL
 
 =pod
 
@@ -133,9 +137,11 @@ C<undef> if not.
 
 =cut
 
+eval <<'END_PERL' unless defined &_IDENTIFIER;
 sub _IDENTIFIER ($) {
 	(defined $_[0] and ! ref $_[0] and $_[0] =~ m/^[^\W\d]\w*$/s) ? $_[0] : undef;
 }
+END_PERL
 
 =pod
 
@@ -154,9 +160,11 @@ C<undef> if not.
 
 =cut
 
+eval <<'END_PERL' unless defined &_CLASS;
 sub _CLASS ($) {
 	(defined $_[0] and ! ref $_[0] and $_[0] =~ m/^[^\W\d]\w*(?:::\w+)*$/s) ? $_[0] : undef;
 }
+END_PERL
 
 =pod
 
@@ -178,9 +186,11 @@ C<undef> if not.
 
 =cut
 
+eval <<'END_PERL' unless defined &_CLASSISA;
 sub _CLASSISA ($$) {
 	(defined $_[0] and ! ref $_[0] and $_[0] =~ m/^[^\W\d]\w*(?:::\w+)*$/s and $_[0]->isa($_[1])) ? $_[0] : undef;
 }
+END_PERL
 
 =pod
 
@@ -202,9 +212,35 @@ C<undef> if not.
 
 =cut
 
+eval <<'END_PERL' unless defined &_SUBCLASS;
 sub _SUBCLASS ($$) {
 	(defined $_[0] and ! ref $_[0] and $_[0] =~ m/^[^\W\d]\w*(?:::\w+)*$/s and $_[0] ne $_[1] and $_[0]->isa($_[1])) ? $_[0] : undef;
 }
+END_PERL
+
+=pod
+
+=head2 _NUMBER $scalar
+
+The C<_NUMBER> function is intended to be imported into your
+package, and provides a convenient way to test to see if a value is
+a number. That is, it is defined and perl thinks it's a number.
+
+This function is basically a Params::Util-style wrapper around the
+L<Scalar::Util> C<looks_like_number> function.
+
+Returns the value as a convience, or C<undef> if the value is not a
+number.
+
+=cut
+
+eval <<'END_PERL' unless defined &_NUMBER;
+sub _NUMBER ($) {
+	( defined $_[0] and ! ref $_[0] and Scalar::Util::looks_like_number($_[0]) )
+	? $_[0]
+	: undef;
+}
+END_PERL
 
 =pod
 
@@ -217,11 +253,46 @@ a positive integer (of any length).
 Returns the value as a convience, or C<undef> if the value is not a
 positive integer.
 
+The name itself is derived from the XML schema constraint of the same
+name.
+
 =cut
 
+eval <<'END_PERL' unless defined &_POSINT;
 sub _POSINT ($) {
 	(defined $_[0] and ! ref $_[0] and $_[0] =~ m/^[1-9]\d*$/) ? $_[0] : undef;
 }
+END_PERL
+
+=pod
+
+=head2 _NONNEGINT $integer
+
+The C<_NONNEGINT> function is intended to be imported into your
+package, and provides a convenient way to test to see if a value is
+a non-negative integer (of any length). That is, a positive integer,
+or zero.
+
+Returns the value as a convience, or C<undef> if the value is not a
+non-negative integer.
+
+As with other tests that may return false values, care should be taken
+to test via "defined" in boolean validy contexts.
+
+  unless ( defined _NONNEGINT($value) ) {
+     die "Invalid value";
+  }
+
+The name itself is derived from the XML schema constraint of the same
+name.
+
+=cut
+
+eval <<'END_PERL' unless defined &_NONNEGINT;
+sub _NONNEGINT ($) {
+	(defined $_[0] and ! ref $_[0] and $_[0] =~ m/^(?:0|[1-9]\d*)$/) ? $_[0] : undef;
+}
+END_PERL
 
 =pod
 
@@ -239,9 +310,11 @@ if the value provided is not a C<SCALAR> reference.
 
 =cut
 
+eval <<'END_PERL' unless defined &_SCALAR;
 sub _SCALAR ($) {
 	(ref $_[0] eq 'SCALAR' and defined ${$_[0]} and ${$_[0]} ne '') ? $_[0] : undef;
 }
+END_PERL
 
 =pod
 
@@ -259,9 +332,11 @@ if the value provided is not a C<SCALAR> reference.
 
 =cut
 
+eval <<'END_PERL' unless defined &_SCALAR0;
 sub _SCALAR0 ($) {
 	ref $_[0] eq 'SCALAR' ? $_[0] : undef;
 }
+END_PERL
 
 =pod
 
@@ -279,9 +354,11 @@ if the value provided is not an C<ARRAY> reference.
 
 =cut
 
+eval <<'END_PERL' unless defined &_ARRAY;
 sub _ARRAY ($) {
 	(ref $_[0] eq 'ARRAY' and @{$_[0]}) ? $_[0] : undef;
 }
+END_PERL
 
 =pod
 
@@ -300,9 +377,11 @@ if the value provided is not an C<ARRAY> reference.
 
 =cut
 
+eval <<'END_PERL' unless defined &_ARRAY0;
 sub _ARRAY0 ($) {
 	ref $_[0] eq 'ARRAY' ? $_[0] : undef;
 }
+END_PERL
 
 =pod
 
@@ -314,6 +393,7 @@ C<_ARRAYLIKE> returns C<undef>.
 
 =cut
 
+eval <<'END_PERL' unless defined &_ARRAYLIKE;
 sub _ARRAYLIKE {
 	(defined $_[0] and ref $_[0] and (
 		(Scalar::Util::reftype($_[0]) eq 'ARRAY')
@@ -321,6 +401,7 @@ sub _ARRAYLIKE {
 		overload::Method($_[0], '@{}')
 	)) ? $_[0] : undef;
 }
+END_PERL
 
 =pod
 
@@ -338,9 +419,11 @@ if the value provided is not an C<HASH> reference.
 
 =cut
 
+eval <<'END_PERL' unless defined &_HASH;
 sub _HASH ($) {
 	(ref $_[0] eq 'HASH' and scalar %{$_[0]}) ? $_[0] : undef;
 }
+END_PERL
 
 =pod
 
@@ -358,9 +441,11 @@ if the value provided is not an C<HASH> reference.
 
 =cut
 
+eval <<'END_PERL' unless defined &_HASH0;
 sub _HASH0 ($) {
 	ref $_[0] eq 'HASH' ? $_[0] : undef;
 }
+END_PERL
 
 =pod
 
@@ -372,6 +457,7 @@ C<_HASHLIKE> returns C<undef>.
 
 =cut
 
+eval <<'END_PERL' unless defined &_HASHLIKE;
 sub _HASHLIKE {
 	(defined $_[0] and ref $_[0] and (
 		(Scalar::Util::reftype($_[0]) eq 'HASH')
@@ -379,6 +465,7 @@ sub _HASHLIKE {
 		overload::Method($_[0], '%{}')
 	)) ? $_[0] : undef;
 }
+END_PERL
 
 =pod
 
@@ -393,9 +480,11 @@ if the value provided is not an C<CODE> reference.
 
 =cut
 
+eval <<'END_PERL' unless defined &_CODE;
 sub _CODE ($) {
 	ref $_[0] eq 'CODE' ? $_[0] : undef;
 }
+END_PERL
 
 =pod
 
@@ -412,7 +501,7 @@ almost always end up also testing it in 'bool' context at some stage.
 For example:
 
   sub foo {
-      my $coed1 = _CODELIKE(shift) or die "No code param provided";
+      my $code1 = _CODELIKE(shift) or die "No code param provided";
       my $code2 = _CODELIKE(shift);
       if ( $code2 ) {
            print "Got optional second code param";
@@ -439,7 +528,8 @@ I apologise for any inconvenience caused.
 
 =cut
 
-sub _CODELIKE {
+eval <<'END_PERL' unless defined &_CODELIKE;
+sub _CODELIKE($) {
 	(
 		(Scalar::Util::reftype($_[0])||'') eq 'CODE'
 		or
@@ -447,12 +537,7 @@ sub _CODELIKE {
 	)
 	? $_[0] : undef;
 }
-
-# Will stay around until end-2006 with a warning, then will be deleted.
-sub _CALLABLE {
-	warn "_CALLABLE has been deprecated. Change to _CODELIKE";
-	_CODELIKE(@_);
-}
+END_PERL
 
 =pod
 
@@ -465,7 +550,8 @@ If so, the value itself is returned.  Otherwise, C<_INVOCANT> returns C<undef>.
 
 =cut
 
-sub _INVOCANT {
+eval <<'END_PERL' unless defined &_INVOCANT;
+sub _INVOCANT($) {
 	(defined $_[0] and
 		(defined Scalar::Util::blessed($_[0])
 		or      
@@ -474,6 +560,7 @@ sub _INVOCANT {
 		Params::Util::_CLASS($_[0]))
 	) ? $_[0] : undef;
 }
+END_PERL
 
 =pod
 
@@ -488,9 +575,29 @@ provided is not an object of that type.
 
 =cut
 
+eval <<'END_PERL' unless defined &_INSTANCE;
 sub _INSTANCE ($$) {
 	(Scalar::Util::blessed($_[0]) and $_[0]->isa($_[1])) ? $_[0] : undef;
 }
+END_PERL
+
+=pod
+
+=head2 _REGEX $value
+
+The C<_REGEX> function is intended to be imported into your package,
+and provides a convenient way to test for a regular expression.
+
+Returns the value itself as a convenience, or C<undef> if the value
+provided is not a regular expression.
+
+=cut
+
+eval <<'END_PERL' unless defined &_REGEX;
+sub _REGEX ($) {
+	(defined $_[0] and 'Regexp' eq ref($_[0])) ? $_[0] : undef;
+}
+END_PERL
 
 =pod
 
@@ -511,14 +618,16 @@ the value provided is not a set of that class.
 
 =cut
 
+eval <<'END_PERL' unless defined &_SET;
 sub _SET ($$) {
 	my $set = shift;
-	ref $set eq 'ARRAY' and @$set or return undef;
-	foreach ( @$set ) {
-		Scalar::Util::blessed($_) and $_->isa($_[0]) or return undef;
+	_ARRAY($set) or return undef;
+	foreach my $item ( @$set ) {
+		_INSTANCE($item,$_[0]) or return undef;
 	}
 	$set;
 }
+END_PERL
 
 =pod
 
@@ -539,14 +648,16 @@ the value provided is not a set of that class.
 
 =cut
 
+eval <<'END_PERL' unless defined &_SET0;
 sub _SET0 ($$) {
 	my $set = shift;
-	ref $set eq 'ARRAY' or return undef;
-	foreach ( @$set ) {
-		Scalar::Util::blessed($_) and $_->isa($_[0]) or return undef;
+	_ARRAY0($set) or return undef;
+	foreach my $item ( @$set ) {
+		_INSTANCE($item,$_[0]) or return undef;
 	}
 	$set;
 }
+END_PERL
 
 =pod
 
@@ -571,6 +682,7 @@ detectors in existance (and we stole from the best of them).
 # we'll compress this into something that compiles more efficiently.
 # Further, testing file handles is not something that is generally
 # done millions of times, so doing it slowly is not a big speed hit.
+eval <<'END_PERL' unless defined &_HANDLE;
 sub _HANDLE {
 	my $it = shift;
 
@@ -621,6 +733,7 @@ sub _HANDLE {
 	# This is not any sort of object we know about
 	return undef;
 }
+END_PERL
 
 =pod
 
@@ -648,9 +761,11 @@ or the class fails the isa test.
 
 =cut
 
+eval <<'END_PERL' unless defined &_DRIVER;
 sub _DRIVER ($$) {
 	(defined _CLASS($_[0]) and eval "require $_[0];" and ! $@ and $_[0]->isa($_[1]) and $_[0] ne $_[1]) ? $_[0] : undef;
 }
+END_PERL
 
 1;
 
@@ -660,10 +775,6 @@ sub _DRIVER ($$) {
 
 - Add _CAN to help resolve the UNIVERSAL::can debacle
 
-- More comprehensive tests for _SET and _SET0
-
-- Would be nice if someone would re-implement in XS for me? (done'ish)
-
 - Would be even nicer if someone would demonstrate how the hell to
 build a Module::Install dist of the ::Util dual Perl/XS type. :/
 
@@ -686,11 +797,11 @@ Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 SEE ALSO
 
-L<Params::Validate>, L<http://ali.as/>
+L<Params::Validate>
 
 =head1 COPYRIGHT
 
-Copyright 2005, 2006 Adam Kennedy.
+Copyright 2005 - 2009 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
